mangadap.config package
=======================

Submodules
----------

.. toctree::
   :maxdepth: 4

   mangadap.config.analysisplan
   mangadap.config.defaults
   mangadap.config.manga

Module contents
---------------

.. automodule:: mangadap.config
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
